@@ -18,7 +18,7 @@ def test_compatibility(client, user_schema_v3):
     assert compatibility
 
 
-def test_update_compatibility(client):
+def test_update_compatibility_for_subject(client):
     """
     The latest User V2 schema is  BACKWARD and FORWARDFULL compatibility (FULL).
     So, we can ipdate compatibility level for the specified subject.
@@ -26,6 +26,14 @@ def test_update_compatibility(client):
     assert client.update_compatibility("FULL", "test-user-schema")
 
 
+def test_update_global_compatibility(client):
+    """
+    The latest User V2 schema is  BACKWARD and FORWARDFULL compatibility (FULL).
+    So, we can ipdate compatibility level for the specified subject.
+    """
+    assert client.update_compatibility("FULL")
+
+
 def test_update_compatibility_fail(client, response_klass, mocker):
     http_code = 404
     mocker.patch.object(
@@ -38,8 +46,15 @@ def test_update_compatibility_fail(client, response_klass, mocker):
         assert excinfo.http_code == http_code
 
 
-def test_get_compatibility(client):
+def test_get_compatibility_for_subject(client):
     """
     Test latest compatibility for test-user-schema subject
     """
     assert client.get_compatibility("test-user-schema") == "FULL"
+
+
+def test_get_global_compatibility(client):
+    """
+    Test latest compatibility for test-user-schema subject
+    """
+    assert client.get_compatibility() is not None
